==> ejc-probuilddiary-impl-3.0.0-20250311.012510-144-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonEquipmentEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-设备进出场情况（设备管理员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_equipment")
public class PersonEquipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="lease_num")
    private BigDecimal leaseNum; // 租赁次数
    @TableField(value="purchase_num")
    private BigDecimal purchaseNum; // 采购次数
    @TableField(value="equipment_memo")
    private String equipmentMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目
    @TableField(value="project_id")
    private Long projectId; // 项目id

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public BigDecimal getLeaseNum() {
        return leaseNum;
    }

    public void setLeaseNum(BigDecimal leaseNum) {
        this.leaseNum = leaseNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public String getEquipmentMemo() {
        return equipmentMemo;
    }

    public void setEquipmentMemo(String equipmentMemo) {
        this.equipmentMemo = equipmentMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20250327.060628-149-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonEquipmentEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-设备进出场情况（设备管理员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_equipment")
public class PersonEquipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="lease_num")
    private BigDecimal leaseNum; // 租赁次数
    @TableField(value="purchase_num")
    private BigDecimal purchaseNum; // 采购次数
    @TableField(value="equipment_memo")
    private String equipmentMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public BigDecimal getLeaseNum() {
        return leaseNum;
    }

    public void setLeaseNum(BigDecimal leaseNum) {
        this.leaseNum = leaseNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public String getEquipmentMemo() {
        return equipmentMemo;
    }

    public void setEquipmentMemo(String equipmentMemo) {
        this.equipmentMemo = equipmentMemo;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
